package sgc.portal.cs.cs0301.persistence;

import org.apache.ibatis.annotations.Mapper;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cs.cs0301.dto.CS03010001PSearch;
import sgc.portal.cs.cs0301.model.CS03010001P;
import sgc.portal.cs.cs0301.model.TcsDeftVo;
import sgc.portal.cs.cs0301.model.TcsDeftElpsVo;

import java.util.List;

@Mapper
public interface CS03010001PMapper {
	
	List<EasyHashMap<String, Object>> getList(CS03010001PSearch search);
	
	EasyHashMap<String, Object> getListModify(CS03010001PSearch search);

    int insertDeft(TcsDeftVo tcsDeft);
    
    int insertDeftElps(TcsDeftElpsVo tcsDeftElps);
    
    int insertDeftElpsSms(TcsDeftElpsVo tcsDeftElpsSms);

    int updateDeft(TcsDeftVo tcsDeft);
    
    /*삭제*/
    int getDeftElpsCnt(TcsDeftVo tcsDeft);
    int deleteDeftElps(TcsDeftVo tcsDeft);
    int deleteDeft(TcsDeftVo tcsDeft);
}
